#!/usr/bin/env python
import math
"""List of all constants available

Call function tiquations.help for more info
"""
pi = math.pi
eulersnum= math.e
tau = math.tau
eulersmasch = 0.577215664901532860606512
golden_ratio = 1.6180339887498948420
light_speed = 299792458
avogadro = 6.02214076e23
boltzmann = 1.380649e-23
gas_constant = 8.314462618
luminous_efficacy= 683
atmosphere=101325
speed_of_light = 299792458
planck=6.62607004e-34



#Package created by Tinos Psomadakis
#Version 2.0
import os
import math

#Quadratic formula solver
def quadratic(num1,num2,num3):
    """Usage: (NUMx^2)=num1 (NUMx)=num2 (NUM)=num3 Example: 3x^2+5x-2 num1=3, num2=5, num3=-2"""
    last=math.sqrt(num2**2 - 4 * (num1) * (num3))
    result1 = -num2 + last
    ans1 = (result1 / (2 * num1))
    result2 = -num2 - last
    ans2 = (result2 / (2 * num1))
    return ans1, ans2

def pythagoras(a=None, b=None, c=None):
    """Given two sides of a triangle abc, solve for the missing side.

Usage: pythagoras(a=3,c=4) leaving out the side you want to solve for."""

    have_a, have_b, have_c = a is not None, b is not None, c is not None

    if not have_a and have_b and have_c:
        return math.sqrt((c**2)-(b**2))
    if have_a and not have_b and have_c:
        return math.sqrt((c**2)-(a**2))
    if have_a and have_b and not have_c:
       return math.sqrt((a**2)+(b**2))

    raise Exception("You must specify exactly two sides.")

#Solve distance using speed and time
def distance_dst(speed, time):
    """Usage: distance_dst(speed of object, time taken to get there)"""
    return speed*time

#Solve speed using distance and time
def speed_dst(distance, time):
    """Usage: speed_dst(distance traveled, time taken)"""
    return distance/time

#Solve time using speed and distance
def time_dst(distance, speed):
    """Usage: time_dst(distance traveled, speed of object)"""
    return distance/speed

#Solve force using mass and acceleration
def force_fma(mass,acceleration):
    """Usage: force_fma(mass of object, acceleration)"""
    return mass*acceleration


#Solve mass using force and acceleration
def mass_fma(force,acceleration):
    """Usage: mass_fma(force of object, acceleration of object)"""
    return force/acceleration


#Solve acceleration using mass and force
def acceleration_fma(force,mass):
    """Usage: acceleration_fma(force of object, mass of object)"""
    return force/mass


#Solve weight using mass and gravitational field strength
def weight_wmg(mass, gravitational_field_strength):
    """Usage: weight_wmg(Mass of object, gravitational field strength)"""
    return mass*gravitational_field_strength


#Solve mass using weight and gravitational field strength
def mass_wmg(weight, gravitational_field_strength):
    """Usage: mass_wmg(weight (Newtons), gravitational field strength)"""
    return weight/gravitational_field_strength


#Solve gravitational field strength using weight and mass
def gravity_wmg(weight, mass):
    """Usage: gravity_wmg(weight of object, mass of object)"""
    return weight/mass


#Solve for area of circle using radius
def circle_area_rad(radius):
    """Usage: Find circle's area from radius"""
    return math.pi*(radius**2)


#Solve for area of circle using diameter
def circle_area_dia(diameter):
    """Usage: Find circle's area from diameter"""
    return (1/4)*(math.pi*(diameter**2))


#Solve for diameter of circle using radius
def circle_diam_rad(radius):
    """Usage: Find circle's diameter from radius"""
    return radius*2


#Solve for diameter of circle using area
def circle_diam_are(area):
    """Usage: Find circle#s diameter from the area"""
    return 2*(math.sqrt(area/math.pi))


#Solve for circumference of circle using area
def circle_circum_rad(radius):
    """Usage: Find circumference from radius"""
    return 2*(math.pi*radius)


#Solve acceleration using Change in velocity and time
def acceleration_avt(delta_velocity,time):
    """Usage: acceleration_avt(change in speed, time taken)"""
    return delta_velocity/time


#Solve Change in velocity using acceleration and time
def delta_velocity_avt(acceleration,time):
    """Usage: delta_velocity_avt(acceleration of object, time taken)"""
    return acceleration*time


#Solve time taken using acceleration and change in velocity
def time_avt(acceleration,delta_velocity):
    """Usage: time_avt(acceleration of object, change in speed)"""
    return delta_velocity/acceleration


#Solve pressure using force and area
def pressure_fpa(force, area):
    """Usage: pressure_fpa(force of object, areaof object)"""
    return force/area


#Solve force using pressure and area
def force_fpa(pressure, area):
    """Usage: force_fpa(pressure, area of object)"""
    return pressure/area


#Solve area using pressure and force
def area_fpa(force, pressure):
    """Usage: area_fpa(force of object, pressure)"""
    return force*pressure


#Solve volume of a cylinder
def cylinder_vol(radius,height):
    """Usage: find volume of a cylinder"""
    return math.pi*(radius**2*(height))


#Solve surface area of a cylinder
def cylinder_surface_are(radius,height):
    """Usage: Find surface area of a cylinder"""
    return (2*(math.pi*radius*height))+2*(math.pi*(radius**2))


#Solve area of a trapezoid
def trapezoid_area(base_short,base_long,height):
    """Usage: Find the area of a trapezoid"""
    return ((base_short+base_long)/2)*height


#Solve height of a trapezoid
def trapezoid_height(base_short,base_long,area):
    """Usage: Find height of a trapezoid"""
    return 2*(area/(base_short+base_long))


#Solve surface area of a trapezoid
def trapezoid_surface_are(base_short,base_long,height):
    """Usage: Find the surface area of a trapezoid"""
    return ((base_short+base_long)/2)*height


def energy_evq(voltage,charge):
    """Usage: energy_evq(voltage, charge)"""
    return voltage*charge


def voltage_evq(energy,charge):
    """Usage: voltage_evq(energy, charge)"""
    return energy/charge


def charge_evq(energy,voltage):
    """Usage: charge_evq(energy,voltage)"""
    return energy/voltage


def power_piv(current, voltage):
    """Usage: power_piv(current, voltage)"""
    return current*voltage


def current_piv(power, voltage):
    """Usage: current_piv(power, voltage)"""
    return power/voltage


def voltage_piv(power, current):
    """Usage: voltage_piv(power,current)"""
    return power/current

def power_pet(energy,time):
    """Usage: power_pet(energy,time)"""
    return energy/time

def energy_pet(power,time):
    """Usage: energy_pet(power,time)"""
    return power*time

def time_pet(power,energy):
    """Usage: time_pet(power,energy)"""
    return energy/power

def sequence_nth(first_term,term_number,common_difference):
    """Usage: Find the nth term of a sequence"""
    return first_term+(common_difference*(term_number-1))

def sequence_first(nth,term_number,common_difference):
    """Usage: Find first number from a sequence"""
    return nth-(common_difference*(term_number-1))

def sequence_difference(nth,first_term,term_number):
    """Usage: Find the difference in a sequence"""
    return (nth-first_term)/(term_number-1)

def sequence_termnum(nth,first_term,common_difference):
    """Usage: Find the term number in a sequence"""
    return ((nth-first_term)/common_difference)+1

def orbitalspeed_vrt(radius,time):
    """Usage: orbitalspeed_vrt(radius of orbit, time taken)"""
    return (2*(math.pi)*radius)/time

def radius_vrt(orbitalspeed,time):
    """Usage: radius_vrt(orbit speed, time taken)"""
    return (orbitalspeed*time)/(2*math.pi)

def orbittime_vrt(orbitalspeed,radius):
    """Usage: orbittime_vrt(orbital speed, radius of orbit)"""
    return (2*math.pi*radius)/orbitalspeed

def cosine_side_a(b,c,angle_A):
    """Usage: Find side a"""
    return math.sqrt((b**2+c**2)-(2*(b*c*math.cos(angle_A))))

def cosine_side_b(a,c,angle_B):
    """Usage: Find side b"""
    return math.sqrt(a**2+c**2-(2*a*c*math.cos(angle_B)))

def cosine_side_c(a,b,angle_C):
    """Usage: Find side c"""
    return math.sqrt(a**2+b**2-(2*a*b*math.cos(angle_C)))

def cosine_angle_A(a,b,c):
    """Usage: Find angle A"""
    return math.acos(((b**2+c**2)-a**2)/(2*b*c))

def cosine_angle_B(a,b,c):
    """Usage: Find angle B"""
    return math.acos(((a**2+c**2)-b**2)/(2*a*c))

def cosine_angle_C(a,b,c):
    """Usage: Find angle C"""
    return math.acos(((a**2+b**2)-c**2)/(2*a*b))

def energy_emc(mass,speedoflight):
    """Usage: energy_emc(mass of object, speed of light) - You can use the constant light_speed."""
    return mass*speedoflight**2

def mass_emc(energy,speedoflight):
    """Usage: mass_emc(energy of an object, speed of light) - You can use the constant light_speed."""
    return energy/(speedoflight**2)

def speedoflight_emc(energy,mass):
    """Usage: Find the speed of light using energy and mass"""
    return math.sqrt(energy/mass)

def schwarzschild(gravity,mass,speedoflight):
    """Usage: schwarzschild(gravity, mass, speed of light) - Note: you can use the constant earth_g for the earth's gravity and light_speed for the speed of light."""
    return (2*gravity*mass)/(speedoflight**2)

def sphere_mass(density,radius):
    """Usage: Find the mass of a sphere using density and radius"""
    return density*((4/3)*(math.pi)*radius**3)

def sphere_density(mass,radius):
    """Usage: Find the density of a sphere using mass and radius"""
    return mass/((4/3)*math.pi*radius**3)

def sphere_radius(mass,density):
    """Usage: Find the radius of a sphere knowing mass and density"""
    return (mass/(density*(4/3)*math.pi))** (1. / 3)

def cube_vol(side_length):
    """Usage: cube_volume(Side of one length)"""
    return side_length**3

def rectangle_vol(length,width,height):
    """Usage: rectangle_vol(length rectangle, width of rectangle, height of rectangle)"""
    return length*width*height

def sphere_vol(radius):
    """Usage: Find the volume of a sphere using the radius"""
    return (4*math.pi*(radius**3))/3

def cone_vol(radius,height):
    """Usage: Find the volume of a cone using radius and height"""
    return (math.pi*(radius**2)*height)/3

def pyramid_vol(base_area,height):
    """Usage: Find the volume of a pyramid  using base area and height"""
    return (base_area*height)/3

#GitHub SirEraz

def force_fmg(mass,gravitational_field_strength):
    """Usage: Find force of gravity using mass and a gravitational constant """
    return mass * gravitational_field_strength
#(f(g)=mg) find mass using force of grav and g
def mass_fmg(force,gravitational_field_strength):
    """Usage: Find mass using force of gravity and a gravitational constant """
    return force / gravitational_field_strength
#(f(g)=mg) find grav constant using force of g and mass
def gravity_fmg(force,mass):
    """Usage: Find gravity using force and mass """
    return force / mass

def friction_fnc(normal_force,friction_coefficient):
    """Usage: Find force of friction using normal force and friction coefficent"""
    return normal_force * friction_coefficient
#(F(f)=u*F(n)) finds normal force (F(n)) using F(f) and friction coefficient (u)
def normal_fnc(friction_force,friction_coefficient):
    """Usage: Find normal force using force of friction and friction coefficent"""
    return friction_force / friction_coefficient
#(F(f)=u*F(n)) finds friction coefficient (u) using F(f) and F(n)
def coefficient_fmc(friction_force,normal_force):
    """Usage: Find friction coefficent using force of friction and normal force"""
    return friction_force / normal_force

def acceleration_aug(friction_coefficient,gravity):
    """Usage: Find acceleration using friction coefficient and gravitational constant"""
    return friction_coefficient * gravity
#(a=ug) find fric. coefficient (u) using acceleration and grav constant
def coefficient_aug(acceleration,gravity):
    """Usage: Find friction coefficient using acceleration and gravitational constant"""
    return acceleration / gravity
#(a=ug) find grav constant using u and a
def gravity_aug(acceleration,friction_coefficient):
    """Usage: Find gravitational constant using acceleration and friction coefficient"""
    return acceleration / friction_coefficient

def coefficient_cfn(friction,normal):
    """Usage: Find coefficient with friction and normal force"""
    return friction / normal
#(u=F(f)/F(n)) find F(f) with u and F(n)
def friction_cfn(coefficient,normal):
    """Usage: Find friction using coefficient and normal force"""
    return coefficient * normal
#(u=F(f)/F(n)) find F(n) with u and F(f)
def normal_cfn(coefficient,friction):
    """Usage: Find normal force using coefficient and friction"""
    return friction / coefficient

def radius_rf(focal_point):
    """Usage: radius with focal point for concave and convex mirrors"""
    return 2 *focal_point
#(C=2f) find focal point with C
def focal_rf(radius):
    """Usage: focal point with radius for concave and convex mirrors"""
    return radius / 2

#(f=(di*do/di+do)) find focal point (f) with d(i) and d(o)
def focal_point(distance_image,distance_object):
    """Usage: Find focal point with distance of image and distance of object"""
    numerator = distance_image * distance_object
    denominator = distance_image + distance_object
    return numerator / denominator
#d(i)=(f*do/do-f) find d(i) with focal point and d(o)
def mirror_distance_image(focal_point,distance_object):
    """Usage: Find distance of image with focal point and distance of object"""
    numerator = focal_point * distance_object
    denominator = distance_object - focal_point
    return numerator / denominator
#d(o)=(f*di/di-f) find d(o) with focal point and d(i)
def mirror_distance_object(focal_point,distance_image):
    """Usage: Find distance of object with focal point and distance of image"""
    numerator = focal_point * distance_image
    denominator = distance_image - focal_point
    return numerator / denominator

#the following equations are variations of m=(hi/ho)=(-di/do)
#find m with h(i) and h(o)
def mirror_mag_h(height_image,height_object):
    """Usage: Find magnification using height of image and height of object"""
    return height_image/ height_object
#find m with d(i) and d(o)
def mirror_mag_d(distance_image,distance_object):
    """Usage: Find magnification using distance of image and distance of object"""
    neg_di = (-1) * distance_image
    return neg_di / distance_object
#find h(i) with m and h(o)
def mirror_hi_m(magnification,height_object):
    """Usage: Find height of image using magnification and height of object"""
    return magnification * height_object
#find h(i) with d(i), d(o), and h(o)
def mirror_hi_hodido(distance_image,distance_object,height_object):
    """Usage: Find height of image using height of object, distance of object and height of object"""
    neg_di = (-1) * distance_image
    numerator = neg_di * height_object
    return numerator / distance_object
#find h(o) with m and h(i)
def mirror_ho_m(height_image,magnification):
    """Usage: Find height of object using magnification"""
    return height_image / magnification
#find h(o) with d(i), d(o), h(i)
def mirror_ho_hidido(distance_image,distance_object,height_image):
    """Usage: Find height of object using height of image, distance of object and height of object"""
    neg_di = (-1) * distance_image
    numerator = height_image * distance_object
    return numerator / neg_di

#PENDULUMS
#T = period
#L = length of string (of pendulum)
#g = grav constant (acceleration of grav)

#T = 2(math.pi)*sqrt(L/g)

#find T with L and g
def time_tlg(length,gravity):
    """Usage: PENDULUMS - Find time using length and gravity"""
    return (2 * math.pi) *(math.sqrt(length / gravity))
#find L with T and g
def length_tlg(time,gravity):
    """Usage: PENDULUMS - Find length using time and gravity"""
    return gravity * (time / (2 * math.pi))**2
#find g with T and L
def gravity_tlg(time,length):
    """Usage: PENDULUMS - Find gravity using time and length"""
    return (2 * math.pi)**2 / time**2

#END OF SIR ERAZ GITHUB

def wave_frequency_t(time_period):
    """Usage: Finding the wave frequency using time period.
    f=1/T"""
    return 1/time_period

def wave_speed_flv(frequency,wave_length):
    """Usage: Finding the wave speed using frequency and wave length.
    v=f×λ"""
    return frequency*wave_length

def frequency_flv(wave_length,wave_speed):
    """Usage: Finding the frequency using wave speed and wave length.
    f=v/λ"""
    return wave_speed/wave_length

def wave_length_flv(frequency,wave_speed):
    """Usage: Finding the wave length using frequency and wave speed.
    λ=v/f"""
    return wave_speed/frequency

def refractive_index_nir(angle_incidence,angle_refraction):
    """Usage: Find refractive index using angle of incidence and angle of refraction"""
    refractive_index_nir_resul=math.sin(angle_incidence)/math.sin(angle_refraction)
    return refractive_index_nir_resul

def angle_incidence_nir(refractive_index,angle_refraction):
    """Usage: Find angle of incidence using refractive index and angle of refraction
    returns in radians"""
    angle_incidence_nir_resul=refractive_index*math.sin(angle_refraction)
    return angle_incidence_nir_resul

def angle_refraction_nir(refractive_index,angle_incidence):
    """Usage: Find angle of refraction using refractive index and angle of incidence
    returns in radians"""
    angle_refraction_nir_resul=math.sin(angle_incidence)/refractive_index
    return angle_refraction_nir_resul



def kinetic_energy_kmv(mass,velocity):
    """Usage: Find kinetic energy from mass and velocity"""
    result = 0.5*(mass*velocity**2)
    return result

def mass_kmv(kinetic_energy,velocity):
    """Usage: Find mass from kinetic energy and velocity"""
    result = (2*kinetic_energy)/velocity**2
    return result

def velocity_kmv(kinetic_energy,mass):
    """Usage: Find velocity from kinetic energy and mass"""
    result = math.sqrt(kinetic_energy/(0.5*mass))
    return result

def GPE_gpemgh(mass,gravity,height):
    """Usage: Find gravitational potential energy from mass, gravity and height"""
    result=mass*gravity*height
    return result

def mass_gpemgh(GPE,gravity,height):
    """Usage: Find mass from gravitational potential energy, gravity and height"""
    result=GPE/gravity*height
    return result

def gravity_gpemgh(GPE,mass,height):
    """Usage: Find gravity from gravitational potential energy, mass and height"""
    result=GPE/mass*height
    return result

def height_gpemgh(GPE,mass,gravity):
    """Usage: Find height from gravitational potential energy, mass and gravity"""
    result=GPE/mass*gravity
    return result

def wave_period_tf(frequency):
    """Usage: Calculate wave period (T) using frequency (f)"""
    return 1/frequency

def wave_period_tlv(wavelength, velocity):
    """Usage: Calculate wave period (T) using wavelength (l) and velocity (v)"""
    return wavelength/velocity

def wavelength_tlv(wave_period, velocity):
    """Usage: Calculate wavelength (l) using wave period (T) and velocity (v)"""
    return wave_period*velocity

def velocity_tlv(wave_period, wavelength):
    """Usage: Calculate velocity (v) using wave period (T) and wave length(l)"""
    return wavelength/wave_period

def fringe_spacing(wavelength, distance_from_slits_to_screen, slit_separation):
    """Usage: Calculate fringe spacing using wavelength (lambda), distance from slits to screen (D) and slit separation (s)"""
    return ((wavelength*distance_from_slits_to_screen)/slit_separation)

def moment_mfd(force, distance_from_pivot):
    """Usage: Calculate moment from force and the perpendicular distance from the pivot"""
    return force*distance_from_pivot

def force_mfd(moment, distance_from_pivot):
    """Usage: Calculate force from moment and the perpendicular distance from the pivot"""
    return moment/distance_from_pivot

def distance_pivot_mfd(moment, force):
    """Usage: Calculate perpendicular distance from the pivot from force and the moment """
    return moment/force

def energy_photon(frequency, wavelength):
    """Usage: Calculate the energy of a photon using frequency and wavelength """
    equation = ((6.62607004e-34 )*3e+8)/wavelength



#!/usr/bin/env python
from .equations import *
from .constants import *
from .planets import *
from .chemistry import *
from .convert import *
import logging
logging.getLogger(__name__).info("Made using Tiquations 2.0")
__author__="Tinos Psomadakis"
__copyright__="Copyright (c) 2019 Tinos Psomadakis"
__credits__ = ["Creme", "Sir Eraz", "Paul Kienzle"]
__version__ = "1.3"
__maintainer__ = "Tinos Psomadakis"
__email__ = "tinosps@gmail.com"
__status__ = "Release"

def help():
    print('''
        https://www.tiquations.com

        A python package containing useful equations for physics, maths, chemistry and computer science.
        Created by Tinos Psomadakis\n
          ''')
    #Commands
    print("Angles are always measured in radians")
    print("All command examples are shown as: tiquations.x with x being the command example prefix")
    print('''
        Commands:

        equations.quadratic(a,b,c) - Find quadratic formula from an equation like 3x^2+6x+2 = 0 where a=3, b=6 and c=2.
        equations.distance_dst(speed,time) - Find distance using speed and time
        equations.speed_dst(distance,time) - Find speed using distance and time
        equations.time_dst(distance,speed) - Find time using distance and speed
        equations.force_fma(mass,acceleration) - Find force using mass and acceleration
        equations.mass_fma(force,acceleration) - Find mass using force and acceleration
        equations.acceleration_fma(force,mass) - Find acceleration using force and mass
        equations.force_fmg(mass,gravitational_field_strength) - Find force using the mass and gravitational field strength
        equations.mass_fmg(force,gravitational_field_strength) - Find mass using the force and gravitational field strength
        equations.gravity_fmg(force,mass) - Find gravitational field strength using force and mass
        equations.weight_wmg(mass, gravitational_field_strength) - Find weight using mass and gravitational field strength
        equations.mass_wmg(weight, gravitational_field_strength) - Find mass using weight and gravitational field strength
        equations.gravity_wmg(weight, mass) - Find gravitational field strength using weight and mass
        equations.circle_area_rad(radius) - Find area of a circle using radius
        equations.circle_area_dia(diameter) - Find area of a circle using diameter
        equations.circle_diam_rad(radius) - Find diameter of a circle using radius
        equations.circle_diam_are(area) - Find diameter of a circle using area
        equations.circle_circum_rad(radius) - Find circumference of a circle
        equations.acceleration_avt(delta_velocity,time) - Find acceleration using change in velocity and time
        equations.delta_velocity_avt(acceleration,time) - Find change in velocity using acceleration and time
        equations.time_avt(acceleration,delta_velocity) - Find time taken using change in velocity and acceleration
        equations.pressure_fpa(force, area) - Find pressure using force and area
        equations.force_fpa(pressure, area) - Find force using pressure and area
        equations.area_fpa(force, pressure) - Find area using force and pressure
        equations.cylinder_vol(radius,height) - Find volume of cylinder
        equations.cylinder_surface_are(radius,height) - Find surface area of cylinder
        equations.trapezoid_area(base_short,base_long,height) - Find area of trapezoid
        equations.trapezoid_height(base_short,base_long,area) - Find height of trapezoid
        equations.trapezoid_surface_are(base_short,base_long,height) - Find surface are of trapezoid
        equations.pythagoras(a=None, b=None, c=None) - Use pythagoras' theorem to solve for a missing side
        equations.energy_evq(voltage,charge) - Find energy using potential difference and charge
        equations.voltage_evq(energy,charge) - Find potential difference using energy and charge
        equations.charge_evq(energy,voltage) - Find charge using energy and potential difference
        equations.power_piv(current, potential_difference) - Find power using current and potential difference
        equations.current_piv(power, potential_difference) - Find current using power and potential difference
        equations.potential_dif_piv(power, current) - Find potential difference using power and current
        equations.power_pet(energy,time) - Find power using energy and time
        equations.energy_pet(power,time) - Find energy using power and time
        equations.time_pet(power,energy) - Find time using power and energy
        equations.sequence_nth(first_term,term_number,common_difference) - Find nth term of sequence
        equations.sequence_first(nth,term_number,common_difference) - Find the first term of a sequence
        equations.sequence_difference(nth,first_term,term_number) - Find difference of a sequence
        equations.sequence_termnum(nth,first_term,common_difference) - Find term number of a sequence
        equations.orbitalspeed_vrt(radius,time) - Find orbital speed using radius and orbit time
        equations.radius_vrt(orbitalspeed,time) - Find radius using orbital speed and orbit time
        equations.orbittime_vrt(orbitalspeed,radius) - Find orbit time using orbital speed and radius
        equations.cosine_side_a(b,c,A_radians) - Find side a using cosine rule
        equations.cosine_side_b(a,c,B_radians) - Find side b using cosine rule
        equations.cosine_side_c(a,b,C_radians) - Find side c using cosine rule
        equations.cosine_angle_A(a,b,c) - Find angle A using cosine rule
        equations.cosine_angle_B(a,b,c) - Find angle B using cosine rule
        equations.cosine_angle_C(a,b,c) - Find angle C using cosine rule
        equations.energy_emc(mass,speedoflight) - Find energy using mass and speed of light
        equations.mass_emc(energy,speedoflight) - Find mass using energy and speed of light
        equations.speedoflight_emc(energy,mass) - Find speed of light using energy and mass. You can also use the light_speed constant.
        equations.schwarzschild(gravity,mass,speedoflight) - Find the Schwarzschild radius of a black hole
        equations.sphere_mass(density,radius) - Find mass of a sphere using density and radius
        equations.sphere_density(mass,radius) - Find density of a sphere using mass and radius
        equations.sphere_radius(mass,density) - Find radius of a sphere using mass and density
        equations.cube_vol(side_length) - Find the volume of a cube using one side
        equations.rectangle_vol(length,width,height) - Find the volume of a rectangle using length, width and height
        equations.sphere_vol(radius) - Find the volume of a sphere using it's radius
        equations.cone_vol(radius,height) - Find the volume of a cone using the radius and height
        equations.pyramid_vol(base_area,height) - Find the volume of a pyramid using the area of the base and height
        equations.wave_frequency_t(time_period) - Find wave frequency using time
        equations.wave_speed_flv(frequency,wave_length) - Find wave speed using frequency and wave speed
        equations.frequency_flv(wave_length,wave_speed) - Find frequency using wave length and wave speed
        equations.wave_length_flv(frequency,wave_speed)  - Find wave length using frequency and wave speed
        equations.refractive_index_nir(angle_incidence,angle_refraction) - Find refractive index using angle of incidence and angle of refraction
        equations.angle_incidence_nir(refractive_index,angle_refraction) - Find angle of incidence using refractive index and angle of angle_refraction
        equations.angle_refraction_nir(refractive_index,angle_incidence) - Find angle of refraction using refractive index and angle of incidence
        equations.kinetic_energy_kmv(mass,velocity) - Find kinetic energy using mass and velocity
        equations.velocity_kmv(kinetic_energy,mass) - Find velocity using kinetic energy and mass
        equations.mass_kmv(kinetic_energy,velocity) - Find mass using kinetic energy and velocity
        equations.GPE_gpemgh(mass,gravity,height) - Find gravitational potential energy using mass, gravity and height
        equations.mass_gpemgh(GPE,gravity,height) - Find mass using gravitational potential energy, gravity and height
        equations.gravity_gpemgh(GPE,mass,height) - Find gravity using gravitational potential energy, mass and height
        equations.height_gpemgh(GPE,mass,gravity) - Find height using gravitational potential energy, mass and gravity
        equations.friction_fnc(normal_force,friction_coefficient) - Find force of friction using normal force and friction coefficent
        equations.normal_fnc(friction_force,friction_coefficient) - Find normal force using force of friction and friction coefficent
        equations.coefficient_fmc(friction_force,normal_force) - Find friction coefficent using force of friction and normal force
        equations.acceleration_aug(friction_coefficient,gravity) - Find acceleration using friction coefficient and gravitational constant
        equations.coefficient_aug(acceleration,gravity) - Find friction coefficient using acceleration and gravitational constant
        equations.gravity_aug(acceleration,friction_coefficient) - Find gravitational constant using acceleration and friction coefficient
        equations.coefficient_cfn(friction,normal) - Find coefficient with friction and normal force
        equations.friction_cfn(coefficient,normal) - Find friction using coefficient and normal force
        equations.normal_cfn(coefficient,friction) - Find normal force using coefficient and friction
        equations.radius_rf(focal_point) -radius with focal point for concave and convex mirrors
        equations.focal_rf(radius) - focal point with radius for concave and convex mirrors
        equations.focal_point(distance_image,distance_object) - Find focal point with distance of image and distance of object
        equations.mirror_distance_image(focal_point,distance_object) - Find distance of image with focal point and distance of object
        equations.mirror_distance_object(focal_point,distance_image) - Find distance of object with focal point and distance of image
        equations.mirror_mag_h(height_image,height_object) - Find magnification using height of image and height of object
        equations.mirror_mag_d(distance_image,distance_object) - Find magnification using distance of image and distance of object
        equations.mirror_hi_m(magnification,height_object) - Find height of image using magnification and height of object
        equations.mirror_hi_hodido(distance_image,distance_object,height_object) - Usage: Find height of image using height of object, distance of object and height of object
        equations.mirror_ho_m(height_image,magnification) - Find height of object using magnification
        equations.mirror_ho_hidido(distance_image,distance_object,height_image) - Find height of object using height of image, distance of object and height of object
        equations.time_tlg(length,gravity) - PENDULUMS: Find time using length and gravity
        equations.length_tlg(time,gravity) - PENDULUMS: Find length using time and gravity
        equations.gravity_tlg(time,length) - PENDULUMS: Find gravity using time and length

        NEW IN TIQUATIONS 2.0

        convert.Kelvin_C(Celsius) - Convert Celsius to Kelvin
        convert.Kelvin_F(Fahrenheit) - Convert Fahrenheit to Kelvin
        convert.Celsius_K(Kelvin) - Convert Kelvin to Celsius
        convert.Celsius_F(Fahrenheit) - Convert Fahrenheit to Celsius
        convert.Fahrenheit_C(Celsius) - Convert Celsius to Fahrenheit
        convert.Fahrenheit_K(Kelvin) - Convert Kelvin to Fahrenheit
        convert.bits(bytes,kilobytes,megabytes,gigabytes,terabytes,petabytes) - Convert to bits using any of the kwargs
        convert.bytes(bits,kilobytes,megabytes,gigabytes,terabytes,petabytes) - Convert to bytes using any of the kwargs
        convert.kilobytes(bits,bytes,megabytes,gigabytes,terabytes,petabytes) - Convert to kilobytes using any of the kwargs
        convert.megabytes(bits,bytes,kilobytes,gigabytes,terabytes,petabytes) - Convert to megabytes using any of the kwargs
        convert.gigabytes(bits,bytes,kilobytes,megabytes,terabytes,petabytes) - Convert to gigabytes using any of the kwargs
        convert.terabytes(bits,bytes,kilobytes,megabytes,gigabytes,petabytes) - Convert to terabytes using any of the kwargs
        convert.petabytes(bits,bytes,kilobytes,megabytes,gigabytes,terabytes) - Convert to petabytes using any of the kwargs
        convert.km_miles(kilometers) - Convert km to miles
        convert.miles_km(miles) - Convert miles to km
        equations.wave_period_tf(frequency) - Calculate wave period using frequency
        equations.wave_period_tlv(wavelength, velocity) - Calculate wave period using wavelength and velocity
        equations.wavelength_tlv(wave_period, velocity) - Calculate wavelength using wave period and velocity
        equations.velocity_tlv(wave_period, wavelength) - Calculate wave period using wave period and wavelength
        equations.fringe_spacing(wavelength, distance_from_slits_to_screen, slit_separation) - Equation to calculate fringe spacing
        equations.moment_mfd(force, distance_from_pivot) - Calculate moment using force and distance from a pivot
        equations.force_mfd(moment, distance_from_pivot) - Calculate force using moment and distance from a pivot
        equations.distance_pivot_mfd(moment, force) - Calculate distance from a pivot using moment and force
        equations.energy_photon(frequency, wavelength) - Calculate the energy of a proton using frequency and wavelength

        Usage:
        hello = tiquations.equations.example_xyz(5,72)
        testing = tiquations.equations.quadratic(1,2,-3)[0]
        world = tiquations.convert.bit_byte(22)

          ''')

    #Built-in variables
    print('''
        planets.py options:

        Planets:

        planets.earth
        planets.moon (I know this isn't a planet)
        planets.mars
        planets.jupiter
        planets.neptune
        planets.mercury
        planets.saturn
        planets.uranus
        planets.venus
        planets.pluto

        Planets constants:

        index - Integer - Position from sun
        gravity - Float - m/s^2
        mass - Float - kg
        radius - Float - km
        surface_area - Float - million km
        sun_distance - Integer - km
        eccentricity - Float
        volume - Float - km^3
        orbital_period - Integer - days

        Example: tiquations.planets.earth.mass

        Other constants:

        constants.speed_of_light = 299792458 m/s
        constants.pi = 3.141592653589793
        constants.eulersnum = 2.7182818284590452353602874713527
        constants.tau = 6.283185307179586
        constants.eulersmasch = 0.577215664901532860606512
        constants.golden_ratio = 1.6180339887498948420
        constants.light_speed = 299792458 m/s
        constants.boltzmann = 1.380649e−23 J/K
        constants.gas_constant = 8.314462618 J/mol K
        constants.luminous_efficacy = 683 lm/W
        constants.atmosphere = 101325 Pa
        constants.avogadro = 6.02214086 * 10^23 mol^-1
        constants.planck = 6.62607004 * 10^-34 m^2 kg / s

                ''')

    print('''
        Chemistry

        chemistry.py

        Usage: tiquations.chemistry.element_name

        Options:
        symbol - String
        atomic_mass - Float
        atomic_number - Integer

        Examples:
        tiquations.chemistry.hydrogen.symbol
        tiquations.chemistry.calcium.atomic_mass
                ''')

def changelog():
    print(
    '''
    Currently running tiquations Version 2.0
    Changelog:

    - Added orbital period to planets
    - Improved documentation for python built-in help(value) command
    - Added tau constant
    - Moved conversion equations to convert.py instead of equations.py
    - Added conversions for bits, bytes, kilobytes, megabytes, gigabytes, terabytes, petabytes
    - Completely rewrote help command and split changelog and help command into the init so you can do tiquations.help() and tiquations.changelog()
    - Added miles - kilometers conversion
    - Added wave period equations using velocity and wavelength
    - Added Planck's constant
    - Changed tiquations.equations.help() to tiquations.help()
    - Changed tiquations.equations.changelog.help() to tiquations.changelog()

    '''
    )



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="tiquations",
    version="2.0",
    author="Tinos Psomadakis",
    author_email="tinosps@gmail.com",
    description="Tiquations is an Open-Source Python package that is aimed at giving mathematicians and scientists easy access to important equations that they may use often. It was made in python 3.7 and should work on all versions higher than 3.0.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://tiquations.com",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
            ],
)



import math
import os

def Kelvin_C(Celsius):
    """Usage: Convert to Kelvin from Celsius
    Kelvin_C(Celsius)"""
    return Celsius+273.15

def Kelvin_F(Fahrenheit):
    """Usage: Convert to Kelvin from Fahrenheit
    Kelvin_F(Fahrenheit)"""
    return  (Fahrenheit-32) * 5/9 + 273.15

def Celsius_K(Kelvin):
    """Usage: Convert to Celsius from Kelvin
    Celsius_K(Kelvin)"""
    return Kelvin-273.15

def Celsius_F(Fahrenheit):
    """Usage: Convert to Celsius from Fahrenheit
    Celsius_F(Fahrenheit)"""
    return  (Fahrenheit-32)*5/9

def Fahrenheit_C(Celsius):
    """Usage: Convert to Fahrenheit from Celsius
    Fahrenheit_C(Celsius)"""
    return (Celsius* 9/5)+32

def Fahrenheit_K(Kelvin):
    """Usage: Convert to Fahrenheit from Kelvin
    Fahrenheit_K(Kelvin)"""
    return (Kelvin-273.15)*9/5 + 32

def bits(bytes=None, kilobytes=None,megabytes=None,gigabytes=None,terabytes=None,petabytes=None):
    """Usage: Convert to bits. Example: bits(megabytes=23)"""
    if bytes is not None:
        return bytes*8
    elif kilobytes is not None:
        return kilobytes*8000
    elif megabytes is not None:
        return megabytes*8e+6
    elif gigabytes is not None:
        return gigabytes*8e+9
    elif terabytes is not None:
        return terabytes*8e+12
    elif petabytes is not None:
        return petabytes*8e+15
    else:
        raise Exception("You must specify one value. Example: bytes, kilobytes, megabytes, gigabytes, terabytes, petabytes")


def bytes(bits=None, kilobytes=None,megabytes=None,gigabytes=None,terabytes=None,petabytes=None):
    """Usage: Convert to bytes. Example: bytes(gigabytes=2)"""
    if bits is not None:
        return bits/8
    elif kilobytes is not None:
        return kilobytes*1000
    elif megabytes is not None:
        return megabytes*1e+6
    elif gigabytes is not None:
        return gigabytes*1e+9
    elif terabytes is not None:
        return terabytes*1e+12
    elif petabytes is not None:
        return petabytes*1e+15
    else:
        raise Exception("You must specify one value. Example: bits, kilobytes, megabytes, gigabytes, terabytes, petabytes")

def kilobytes(bits=None, bytes=None,megabytes=None,gigabytes=None,terabytes=None,petabytes=None):
    """Usage: Convert to kilobytes. Example: kilobytes(bytes=86237)"""
    if bits is not None:
        return bits/8000
    elif bytes is not None:
        return bytes/1000
    elif megabytes is not None:
        return megabytes*1000
    elif gigabytes is not None:
        return gigabytes*1e+6
    elif terabytes is not None:
        return terabytes*1e+9
    elif petabytes is not None:
        return petabytes*1e+12
    else:
        raise Exception("You must specify one value. Example: bits, bytes, megabytes, gigabytes, terabytes, petabytes")

def megabytes(bits=None, bytes=None,kilobytes=None,gigabytes=None,terabytes=None,petabytes=None):
    """Usage: Convert to megabytes. Example: megabytes(bits=42561261)"""
    if bits is not None:
        return bits/8e+6
    elif bytes is not None:
        return bytes/1e+6
    elif kilobytes is not None:
        return kilobytes/1000
    elif gigabytes is not None:
        return gigabytes*1000
    elif terabytes is not None:
        return terabytes*1e+6
    elif petabytes is not None:
        return petabytes*1e+9
    else:
        raise Exception("You must specify one value. Example: bits, bytes, kilobytes, gigabytes, terabytes, petabytes")

def gigabytes(bits=None, bytes=None,kilobytes=None,megabytes=None,terabytes=None,petabytes=None):
    """Usage: Convert to gigabytes. Example: gigabytes(terabytes=2)"""
    if bits is not None:
        return bits/8e+9
    elif bytes is not None:
        return bytes/1e+9
    elif kilobytes is not None:
        return kilobytes/1e+6
    elif megabytes is not None:
        return megabytes/1000
    elif terabytes is not None:
        return terabytes*1000
    elif petabytes is not None:
        return petabytes*1e+6
    else:
        raise Exception("You must specify one value. Example: bits, bytes, kilobytes, megabytes, terabytes, petabytes")

def terabytes(bits=None, bytes=None,kilobytes=None,megabytes=None,gigabytes=None,petabytes=None):
    """Usage: Convert to terabytes. Example: terabytes(gigabytes=512)"""
    if bits is not None:
        return bits/8e+12
    elif bytes is not None:
        return bytes/1e+12
    elif kilobytes is not None:
        return kilobytes/1e+9
    elif megabytes is not None:
        return megabytes/1e+6
    elif gigabytes is not None:
        return gigabytes/1000
    elif petabytes is not None:
        return petabytes*1000
    else:
        raise Exception("You must specify one value. Example: bits, bytes, kilobytes, megabytes, gigabytes, petabytes")

def petabytes(bits=None, bytes=None,kilobytes=None,megabytes=None,gigabytes=None,terabytes=None):
    """Usage: Convert to petabytes. Example: petabytes(gigabytes=123456)"""
    if bits is not None:
        return bits/ 8e+15
    elif bytes is not None:
        return bytes/1e+15
    elif kilobytes is not None:
        return kilobytes/1e+12
    elif megabytes is not None:
        return megabytes/1e+9
    elif gigabytes is not None:
        return gigabytes/1e+6
    elif petabytes is not None:
        return petabytes/1000
    else:
        raise Exception("You must specify one value. Example: bits, bytes, kilobytes, megabytes, gigabytes, terabytes")

def km_miles(kilometers):
    """Usage: Convert kilometers to miles"""
    return kilometers/1.609

def miles_km(miles):
    """Usage: Convert miles to kilometers"""
    return kilometers*1.609



#!/usr/bin/env python
class Elements(object):
    """Information about elements in the periodic table

    Features:
    symbol - String
    atomic_mass - Float
    atomic_number - Integer

    Example: carbon.atomic_mass
    """
    def __init__(self,symbol,atomic_mass,atomic_number):
        self.symbol=symbol
        self.atomic_mass=atomic_mass
        self.atomic_number=atomic_number

hydrogen=Elements("H",1.00794,1)
helium=Elements("He",4.002602,2)
lithium=Elements("Li",6.941,3)
beryllium=Elements("Be",9.012182,4)
boron=Elements("B",10.811,5)
carbon=Elements("C",12.0107,6)
nitrogen=Elements("N",14.0067,7)
oxygen=Elements("O",15.9994,8)
fluorine=Elements("F",18.9984032,9)
neon=Elements("Ne",20.1797,10)
sodium=Elements("Na",22.98977,11)
magnesium=Elements("Mg",24.305,12)
aluminum=Elements("Al",26.981538,13)
silicon=Elements("Si",28.0855,14)
phosphorus=Elements("P",30.973761,15)
sulfur=Elements("S",32.065,16)
chlorine=Elements("Cl",35.453,17)
argon=Elements("Ar",39.948,18)
potassium=Elements("K",39.0983,19)
calcium=Elements("Ca",40.078,20)
scandium=Elements("Sc",44.95591,21)
titanium=Elements("Ti",47.867,22)
vanadium=Elements("V",50.9415,23)
chromium=Elements("Cr",51.9961,24)
manganese=Elements("Mn",54.938049,25)
iron=Elements("Fe",55.845,26)
cobalt=Elements("Co",58.9332,27)
nickel=Elements("Ni",58.6934,28)
copper=Elements("Cu",63.546,29)
zinc=Elements("Zn",65.409,30)
gallium=Elements("Ga",69.723,31)
germanium=Elements("Ge",72.64,32)
arsenic=Elements("As",74.9216,33)
selenium=Elements("Se",78.96,34)
bromine=Elements("Br",79.904,35)
krypton=Elements("Kr",83.798,36)
rubidium=Elements("Rb",85.4678,37)
strontium=Elements("Sr",87.62,38)
yttrium=Elements("Y",88.90585,39)
zirconium=Elements("Zr",91.224,40)
niobium=Elements("Nb",92.90638,41)
molybdenum=Elements("Mo",95.94,42)
technetium=Elements("Tc",98,43)
ruthenium=Elements("Ru",101.07,44)
rhodium=Elements("Rh",102.9055,45)
palladium=Elements("Pd",106.42,46)
silver=Elements("Ag",107.8682,47)
cadmium=Elements("Cd",112.411,48)
indium=Elements("In",114.818,49)
tin=Elements("Sn",118.71,50)
antimony=Elements("Sb",121.76,51)
tellurium=Elements("Te",127.6,52)
iodine=Elements("I",126.90447,53)
xenon=Elements("Xe",131.293,54)
cesium=Elements("Cs",132.90545,55)
barium=Elements("Ba",137.327,56)
lanthanum=Elements("La",138.9055,57)
cerium=Elements("Ce",140.116,58)
praseodymium=Elements("Pr",140.90765,59)
neodymium=Elements("Nd",144.24,60)
promethium=Elements("Pm",145,61)
samarium=Elements("Sm",150.36,62)
europium=Elements("Eu",151.964,63)
gadolinium=Elements("Gd",157.25,64)
terbium=Elements("Tb",158.92534,65)
dysprosium=Elements("Dy",162.5,66)
holmium=Elements("Ho",164.93032,67)
erbium=Elements("Er",167.259,68)
thulium=Elements("Tm",168.93421,69)
ytterbium=Elements("Yb",173.04,70)
lutetium=Elements("Lu",174.967,71)
hafnium=Elements("Hf",178.49,72)
tantalum=Elements("Ta",180.9479,73)
tungsten=Elements("W",183.84,74)
rhenium=Elements("Re",186.207,75)
osmium=Elements("Os",190.23,76)
iridium=Elements("Ir",192.217,77)
platinum=Elements("Pt",195.078,78)
gold=Elements("Au",196.96655,79)
mercury=Elements("Hg",200.59,80)
thallium=Elements("Tl",204.3833,81)
lead=Elements("Pb",207.2,82)
bismuth=Elements("Bi",208.98038,83)
polonium=Elements("Po",209,84)
astatine=Elements("At",210,85)
radon=Elements("Rn",222,86)
francium=Elements("Fr",223,87)
radium=Elements("Ra",226,88)
actinium=Elements("Ac",227,89)
thorium=Elements("Th",232.0381,90)
protactinium=Elements("Pa",231.03588,91)
uranium=Elements("U",238.02891,92)
neptunium=Elements("Np",237,93)
plutonium=Elements("Pu",244,94)
americium=Elements("Am",243,95)
curium=Elements("Cm",247,96)
berkelium=Elements("Bk",247,97)
californium=Elements("Cf",251,98)
einsteinium=Elements("Es",252,99)
fermium=Elements("Fm",257,100)
mendelevium=Elements("Md",258,101)
nobelium=Elements("No",259,102)
lawrencium=Elements("Lr",262,103)
rutherfordium=Elements("Rf",261,104)
dubnium=Elements("Db",262,105)
seaborgium=Elements("Sg",266,106)
bohrium=Elements("Bh",264,107)
hassium=Elements("Hs",277,108)
meitnerium=Elements("Mt",268,109)
darmstadtium=Elements("Ds",281,110)
roentgenium=Elements("Rg",272,111)
copernicium=Elements("Cn",285,112)
nihonium=Elements("Nh",286,113)
flerovium=Elements("Fl",289,114)
moscovium=Elements("Mc",289,115)
livermorium=Elements("Lv",293,116)
tennessine=Elements("Ts",294,117)
oganesson=Elements("Og",294,118)
